#!/bin/bash
#
# Last update: 2024.8.27


# CreateRemoteIPConf Function

CreateRemoteIPConf(){

File=$1

# 產生 remoteip.conf 設定檔
cat > $File << EOF
LoadModule remoteip_module modules/mod_remoteip.so
RemoteIPHeader X-Forwarded-For
RemoteIPInternalProxy 127.0.0.1
EOF

# 增加 cPanel 本機內外網IP
/scripts/ipusage | awk '{print $1}' | while read ip; do echo -ne "RemoteIPInternalProxy ${ip}\n"; done >> $File

# VPS WAF IP Range
echo 'RemoteIPInternalProxy 103.129.169.0/25' >> $File

# 增加 Cloudflare IP Range
wget -qO- https://www.cloudflare.com/ips-v4 | while IFS= read -r ip || [ -n "$ip" ]; do echo -ne  "RemoteIPInternalProxy ${ip}\n"; done >> $File
wget -qO- https://www.cloudflare.com/ips-v6 | while IFS= read -r ip || [ -n "$ip" ]; do echo -ne  "RemoteIPInternalProxy ${ip}\n"; done >> $File

# 如果有內網IP設定，就移除該行
sed -i '/10.100/d' $File
sed -i '/192.168/d' $File

}

# 如果沒有 remoteip.conf 檔案，就產生
if [ ! -e /usr/local/apache/conf/includes/remoteip.conf ]; then

CreateRemoteIPConf /usr/local/apache/conf/includes/remoteip.conf

# 重啟 Apache 服務
/scripts/restartsrv_httpd  > /dev/null 2>&1

fi

# 產生確認設定檔
CreateRemoteIPConf /mnt/remoteip.conf

# 如果 remoteip.conf 設定IP數量與 ips 設定IP數量不同，就會更新 remoteip.conf，並重啟 httpd 服務 
if ! diff /usr/local/apache/conf/includes/remoteip.conf /mnt/remoteip.conf > /dev/null; then

# 複製確認設定檔
/bin/cp -f /mnt/remoteip.conf /usr/local/apache/conf/includes/remoteip.conf

# 重啟 Apache 服務
/scripts/restartsrv_httpd  > /dev/null 2>&1

fi

# 移除確認設定檔
/bin/rm -f /mnt/remoteip.conf
